BarChartAlignmentToken enum
Token for bar group alignment (maps to fl_chart BarChartAlignment).
Values
- spaceAround → const BarChartAlignmentToken
-
Distribute bars with space around them.
- spaceBetween → const BarChartAlignmentToken
-
Distribute bars with space between them.
- spaceEvenly → const BarChartAlignmentToken
-
Distribute bars with even spacing.
- start → const BarChartAlignmentToken
-
Align bars to the start.
- end → const BarChartAlignmentToken
-
Align bars to the end.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BarChartAlignmentToken> - A constant List of the values in this enum, in order of their declaration.