PieChartLayout class

Resolved layout values for Chart.Pie.

From HostConfig chartsLayout.pie via PieChartLayoutSection.toLayout or ChartsLayoutConfig.resolvePieLayout.

Constructors

PieChartLayout({required double height, required double centerSpaceRadius, required double sectionsSpace, required double sectionRadius, required double titleFontSize, required FontWeight titleFontWeight, required Color titleColor})
Resolved pie or donut chart layout for chart renderers.
const

Properties

centerSpaceRadius double
Inner hole radius; 0 renders a full pie (no donut hole).
final
hashCode int
The hash code for this object.
no setterinherited
height double
Chart area height in logical pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionRadius double
Outer radius of each pie section.
final
sectionsSpace double
Gap between adjacent pie sections.
final
titleColor Color
Text color for on-slice labels.
final
titleFontSize double
Font size for on-slice labels.
final
titleFontWeight FontWeight
Font weight for on-slice labels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited