AdaptiveTappableState class
State for AdaptiveTappable that resolves and invokes selectAction.
- Inheritance
-
- Object
- State<
AdaptiveTappable> - AdaptiveTappableState
- Mixed-in types
Constructors
Properties
- action ↔ GenericAction?
-
Resolved handler for
selectAction, if present in adaptiveMap.getter/setter pair - actionTypeRegistry → ActionTypeRegistry
-
Action handler registry for the current card scope.
no setterinherited
- adaptiveCardElementState → AdaptiveCardElementState
-
State of the root
AdaptiveCardelement widget.no setterinherited -
adaptiveMap
→ Map<
String, dynamic> -
Baseline JSON for this element.
no setterinherited
- cardTypeRegistry → CardTypeRegistry
-
Element factory registry for the current card scope.
no setterinherited
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Same as AdaptiveElementWidgetMixin.id.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- rawRootCardWidgetState → RawAdaptiveCardState
-
Root RawAdaptiveCardState for this card subtree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → String?
-
Lowercased
styletoken from adaptiveMap, if present.no setterinherited - styleResolver → ReferenceResolver
-
HostConfig-backed style resolver for the current card scope.
no setterinherited
- widget → AdaptiveTappable
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
calculateBackgroundImageFit(
String? fillMode) → BoxFit -
Maps Adaptive Card
fillModeto a BoxFit for background images.inherited -
calculateBackgroundImageRepeat(
String? fillMode) → ImageRepeat -
Maps Adaptive Card
fillModeto ImageRepeat tiling behavior.inherited -
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
override
-
didUpdateWidget(
covariant AdaptiveTappable oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
getBackgroundImage(
String url, {ImageRepeat repeat = ImageRepeat.noRepeat, BoxFit fit = BoxFit.cover}) → Widget -
Background Widget for container-style elements; supports network and data URLs.
inherited
-
getBackgroundImageFromMap(
Map element) → Widget? -
Builds a background image widget from an element map's
backgroundImage.inherited -
getBackgroundImageProvider(
String url) → ImageProvider< Object> -
ImageProvider for DecorationImage backgrounds on container-style elements.
inherited
-
getDecorationFromMap(
Map element, {Color? backgroundColor}) → BoxDecoration -
BoxDecoration with optional background color and image from element JSON.
inherited
-
getDecorationImageFromMap(
Map element) → DecorationImage? -
DecorationImage from element JSON
backgroundImage.inherited -
initState(
) → void -
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
resolveBackgroundImage(
dynamic backgroundImage) → ({BoxFit fit, ImageRepeat repeat, String url})? -
Normalizes
backgroundImagestring or object to url/fit/repeat for container elements.inherited -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited