PieChartLayoutSection class
HostConfig chartsLayout.pie / chartsLayout.donut section.
Constructors
- PieChartLayoutSection({required double height, required double centerSpaceRadius, required double sectionsSpace, required double sectionRadius, required double titleFontSize, required FontWeight titleFontWeight, required Color titleColor})
-
HostConfig overrides for pie, donut, and gauge chart layout.
const
-
PieChartLayoutSection.fromJson(Map<
String, dynamic> json, {PieChartLayoutSection? defaults}) -
Parses
chartsLayout.pieorchartsLayout.donutfrom HostConfig JSON.factory
Properties
- centerSpaceRadius → double
-
Inner hole radius;
0renders a full pie (no donut hole).final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Chart area height in logical pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionRadius → double
-
Outer radius of each pie section.
final
- sectionsSpace → double
-
Gap between adjacent pie sections.
final
- titleColor → Color
-
Text color for on-slice labels.
final
- titleFontSize → double
-
Font size for on-slice labels.
final
- titleFontWeight → FontWeight
-
Font weight for on-slice labels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toLayout(
) → PieChartLayout - Resolved values for chart widgets at render time.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited